@@ -7,8 +7,8 @@ module ActiveJob
   module VERSION
     MAJOR = 4
     MINOR = 2
-    TINY  = 4
-    PRE   = nil
+    TINY  = 5
+    PRE   = "2"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
